clear all
clc
%% This is the code for calibration
global beta alpha phi psi sig theta kappa b Nd zh
global tau tk tw rhom rhos
global zeta gamma a delta Al As fe df afl lambda
global Z Gamma B Rl Rs 
global r rl fl phistar phibar fs fsbar nl yl ns ys
global cost_monitor cost_entry cost_services y0 h0 c0 Ni N g P C ge Y K
global gt h0t Nt c0t zht 
%% 1- Preset values

% Standard parameters
psi=1/(1-0.8); % elaticity of sub btw c0 and C
beta=0.960; % discount factor
alpha=0.640; % labor share
phi= 0.100; % depreciation rate
sig=0.85; % Elasticty of sub between diff good
theta=1.059; % Pareto scale

% Tax System
tau=0.1633; % VAT
tk=0.3466; % capital tax- combined median
tw=0.3833; % payroll tax
rhom=0.210; % recovery rate- loans
rhos=0.210; % recovery rate- payment

% Financial Sector
zeta=0.332; % share of labor cost in bank (operating) costs
gamma=zeta; % same for both types of service
lambda=0.457; % payment intensity via bank service
delta=0.03; % default probability
% Am, As, fe are calibrated below

% Other constants
Z=zeta^zeta*(1-zeta)^(1-zeta);
Gamma=gamma^gamma*(1-gamma)^(1-gamma);
B=alpha^alpha*(1-alpha)^(1-alpha);
Rl=rhom+(1-rhom)*(1+tau);
Rs=rhos+(1-rhos)*(1+tau);

% Equilibrium interest rate
r=(1/beta-1)/(1-tk)+phi;

%% 2- Calibrated parameters
% As is chosen to target 1.5% of a $1 payment
fsbar=0.015;
As=Rs^gamma*(1+rhos*tau*(1-gamma+gamma/Rs))/fsbar/Gamma;
ns=((1-gamma)*Rs/gamma)^gamma/As;
ys=((1-gamma)*Rs/gamma)^(gamma-1)/As;
fs= Rs^gamma/As/Gamma;

% ca=a*fl is chosen to match interest rate spread
sprd=0.022;
afl=(1-delta)*sprd-delta*r;
rl=(r+afl)/(1-delta);

% fm/fe ratio is chosen to match firm survival rate of 80%
psurv=0.80;
phistar=psurv^-(1/theta);
phibar=theta*phistar/(theta-1);
df=phistar^theta*(1-beta*(1-delta))*(theta-1);

%% 3- Calibrated parameters (Simultaneously)
% Choose fe to make average firm size equal to 13.4
% n(phibar)/N=1/(1-delta)/g=13.4
npt=13.4;
% Choose kappa and b to make N=0.20 h0=0.89*N=0.178 

% Choose zh to make share of home production 25% 
gt=1/npt/(1-delta); % fe
Nt=0.20; % b
h0t=0.89*Nt; % kappa
zht=0.25; % zh matches c0/(y0+PY)
lb=[0.3;0.4;0.3;0.3];
ub=[10;0.85;0.9;0.9];
opts = optimoptions(@fmincon,'TolX',10.0^-12,'Algorithm','interior-point','Display','off');
x0=[    5.3825 %fe
    0.4728 % kappa
    0.5076 % b
    0.4033 % zh
];
x = fmincon(@(x)0,x0,[],[],[],[],lb,ub,@nfunc,opts);

%print some output on the screen

[g gt; h0 h0t;N Nt; c0/(y0+P*Y) zht ]


[d,dd]=nfunc(x)
fl
Al
As
a

%% 3- Check eqm values/Ratios
options=optimset('TolFun',10.0^-8,'TolX',10.0^-8);
g=fzero(@(x) pfunc(x),[10.0^-8,100000],options);
pfunc(g);

fprintf('Share of banking input in total GDP: %8.4f\n', ...
    (cost_monitor+cost_services)/(y0+P*Y))
fprintf('Share of bank labor in total employment: %8.4f\n', ...
    ((g+a*K)*nl+ns*lambda*(1+tau)*P*C)/N)
fprintf('Share of loan fee in total credit: %8.4f\n', ...
    g*fl/K)
fprintf('Share of entry cost in total GDP: %8.4f\n', ...
    cost_entry/(y0+P*Y))
fprintf('Share of transfer in total GDP: %8.4f\n', ...
    (1-rhom)*tau*yl*(g+a*K)/(y0+P*Y))
fprintf('Share of profits in total GDP: %8.4f\n', ...
    ((1-sig)*P*Y-g*fl-ge*fe)/(y0+P*Y))
fprintf('Share of labor income in total GDP: %8.4f\n', ...
    N/(y0+P*Y))
fprintf('Share of capital income in total GDP: %8.4f\n', ...
    r*K/(y0+P*Y))
