function R = pfunc(g)
global alpha phi psi sig theta a delta tau tw fl fe B rl phistar phibar ...
    P ge Y K I C nl ns yl ys fsbar N Ni cost_monitor cost_entry ...
    lambda cost_services y0 kappa b Nd c0 zh h0 c1 c2 u eta xi ctil
%Calculates P, Price Index in eqm
%   Uses the labor market clearing condition and definition of P and Y

%% 1- find ge (given g) suing the stability condition
ge= phistar^theta*delta*g;

%% 2- find Y=C (given g) using the final goods market clearing/zero profit condition
Y=(1-delta)*g*(P*sig*B*rl^(alpha-1))^(sig/(1-sig))*phibar;
C=Y;
c2=lambda*C;
c1=(1-lambda)*C;
u=xi*c1^(1-eta)*c2^eta;
%% 3- find K=m (given P) using the capital market clearing
K=sig*(1-alpha)*P*Y/(1-delta)/rl;
I=phi*K;

%% 4- find labor demand 
Ni=alpha*sig*P*Y;
cost_monitor=(nl+yl)*(g+a*K);
cost_services=(ns+ys)*lambda*(1+tau)*P*C;
cost_entry=ge*fe;


Nd=Ni+I+cost_monitor+cost_entry+cost_services; % services+consumption

%% 5- Find c0 and labor supply
c0=min(zh,((1+tau)*P*(1+fsbar)*zh*(1-kappa)*c2/(1-tw)/kappa/eta/u^(1-1/psi))^psi);
ctil=(kappa*u^(1-1/psi)+(1-kappa)*c0^(1-1/psi))^(psi/(psi-1));
h0=c0/zh;
Ns=1-c0/zh-(1-b)*ctil^(1-1/psi)*c0^(1/psi)/zh/b/(1-kappa);

%% 6- check labor market clearing

N=Ns;
y0=I+cost_services;
%%
R=Ns-Nd;
end

