%% This is the code for the benchmark case, profit tax, five regimes described in the main text
clear all
clc

%% Cases:
% Benchmark: rhos=0, rhom=0.
% Case 1: rhos=0, rhom=1.
% Case 2: rhos=1, rhom=0.
% Case 3: rhos=1, rhom=1.
% Case 4: rhos=zr, rhom=1/zr. (comparable to 1/3)
% Case 5: rhos=zr, rhom=0. (comparable to bench/2)
% Profit tax: rhos=0, rhom=1, fixedentry=1 (comparable to 2)

%% Description of variables of eqm
% Eqm00: eqm when rhos=0, rhom=0
% Eqm01: eqm when rhos=1, rhom=0
% Eqm11: eqm when rhos=1, rhom=1
% Eqm11z: eqm when rhos=zr, rhom=1
% Eqm10z: eqm when rhos=zr, rhos=0 

% tax neutral counterparts
% Eqm00t: eqm when rhos=0, rhom=0
% Eqm01t: eqm when rhos=1, rhom=0
% Eqm11t: eqm when rhos=1, rhom=1
% Eqm11zt: eqm when rhos=zr, rhom=1
% Eqm10zt: eqm when rhos=zr, rhos=0 

% welfare neutral counterparts
% Eqm00w: eqm when rhos=0, rhom=0
% Eqm01w: eqm when rhos=1, rhom=0
% Eqm11w: eqm when rhos=1, rhom=1
% Eqm11zw: eqm when rhos=zr, rhom=1
% Eqm10zw: eqm when rhos=zr, rhos=0 

%% globals
global beta alpha phi psi sig theta 
global tau tk tw kappa rhom rhos
global zeta gamma lambda delta Al As fe a b zh
global Z Gamma B Rl Rs
global nl ns yl ys fl ftax fs fsbar phistar phibar r rl g P Y N y0 Ni ge K I C
global cost_monitor cost_entry cost_services c0 h0 Inc tauold c1 c2 u ctil eta xi
global options zerorated fixentry spending

%% Parameters
% Calibrated Parameters
psi=1/(1-0.800);
fe=5.3825;
kappa=0.4728;
b= 0.5076;
zh= 0.4033;
Al=71.9763;
As=135.3731;
a=0.6015;


% Production and consumer preferences
beta=0.96; % discount factor
alpha=0.64; % labor share
phi= 0.1; % depreciation rate
sig=0.85; % Elasticty of sub between diff good
theta=1.059;%1.059; % Pareto scale


% Tax System
tk=0.3466; % capital tax- combined median
tw=0.3833; % payroll tax

% Financial Sector
zeta=0.332; % share of labor cost in bank (operating) costs
gamma=zeta; % same for both types of service
lambda=0.458; % payment intensity via bank service
delta=0.03; % default probability

% Other constants
Z=zeta^zeta*(1-zeta)^(1-zeta);
Gamma=gamma^gamma*(1-gamma)^(1-gamma);
B=alpha^alpha*(1-alpha)^(1-alpha);

% Equilibirum values (fixed)
r=(1/beta-1)/(1-tk)+phi;

options=optimset('TolFun',10.0^-15,'TolX',10.0^-15);
fixentry=0;

%% calibrate eta and xi at the benchmark regimewith constant lambda
Cb=0.271740038634590;
fsbarb=0.014665901329098;
lambdab=lambda;
eta=lambdab*(1+fsbarb)/(1-lambdab+lambdab*(1+fsbarb));
xi=(1+(1+fsbarb)*(1-eta)/eta)/((1+fsbarb)*(1-eta)/eta)^(1-eta);

%% Table 1: constant tau
% Find eqm with rhom=rhos=0 at tau=0.1633 (calibrated value). Record eqm values
tau=0.1633;
tauold=tau;
rhos=0;
rhom=0;
zerorated=0;

Eqm00=eqm_solve();
out00=y0+P*Y;

% case 1:
rhos=0;
rhom=1;
zerorated=0;
Eqm01=eqm_solve();
Dyn01=decomp(Eqm01,Eqm00);
wel01=cvfunc(Eqm00(20))/out00;

% column 1: the order of the printed outcomes follows the text
fprintf('Table 1 Column 1\n')
100*[-theta*log(Eqm01(4)/Eqm00(4)); log(Eqm01(7)/Eqm00(7)); ...
  log(Eqm01(6)/Eqm00(6)); log(Eqm01(11)/Eqm00(11));  ...
  log(Eqm01(19)/Eqm00(19)); log(Eqm01(13)/Eqm00(13)); log(Eqm01(14)/Eqm00(14)); ...
  log(sum(Eqm01(15:18))/sum(Eqm00(15:18)));log((y0+P*Y)/out00); wel01]

% case 2:
rhos=1;
rhom=0;
zerorated=0;
Eqm10=eqm_solve();
wel10=cvfunc(Eqm00(20))/out00;
lambda
% column 2:
fprintf('Table 1 Column 2\n')
100*[-theta*log(Eqm10(4)/Eqm00(4)); log(Eqm10(7)/Eqm00(7)); ...
  log(Eqm10(6)/Eqm00(6)); log(Eqm10(11)/Eqm00(11));  ...
  log(Eqm10(19)/Eqm00(19)); log(Eqm10(13)/Eqm00(13)); log(Eqm10(14)/Eqm00(14)); ...
  log(sum(Eqm10(15:18))/sum(Eqm00(15:18))); log((y0+P*Y)/out00); wel10]


% case 3:
rhos=1;
rhom=0;
zerorated=1;
Eqm10z=eqm_solve();
wel10z=cvfunc(Eqm00(20))/out00;

% column 3:
fprintf('Table 1 Column 3\n')
100*[-theta*log(Eqm10z(4)/Eqm00(4)); log(Eqm10z(7)/Eqm00(7)); ...
  log(Eqm10z(6)/Eqm00(6)); log(Eqm10z(11)/Eqm00(11));  ...
  log(Eqm10z(19)/Eqm00(19)); log(Eqm10z(13)/Eqm00(13)); log(Eqm10z(14)/Eqm00(14)); ...
  log(sum(Eqm10z(15:18))/sum(Eqm00(15:18))); log((y0+P*Y)/out00); wel10z]
lambda

% case 4:
rhos=1;
rhom=1;
zerorated=0;
Eqm11=eqm_solve();
wel11=cvfunc(Eqm00(20))/out00;

% column 4:
fprintf('Table 1 Column 4\n')
100*[-theta*log(Eqm11(4)/Eqm00(4)); log(Eqm11(7)/Eqm00(7)); ...
  log(Eqm11(6)/Eqm00(6)); log(Eqm11(11)/Eqm00(11));  ...
  log(Eqm11(19)/Eqm00(19)); log(Eqm11(13)/Eqm00(13)); log(Eqm11(14)/Eqm00(14)); ...
  log(sum(Eqm11(15:18))/sum(Eqm00(15:18))); log((y0+P*Y)/out00); wel11]

% case 5:
rhos=1;
rhom=1;
zerorated=1;
Eqm11z=eqm_solve();
wel11z=cvfunc(Eqm00(20))/out00;

% column 5:
fprintf('Table 1 Column 5\n')
100*[-theta*log(Eqm11z(4)/Eqm00(4)); log(Eqm11z(7)/Eqm00(7)); ...
  log(Eqm11z(6)/Eqm00(6)); log(Eqm11z(11)/Eqm00(11)); log(Eqm11z(19)/Eqm00(19)); ...
  log(Eqm11z(13)/Eqm00(13)); log(Eqm11z(14)/Eqm00(14)); ...
  log(sum(Eqm11z(15:18))/sum(Eqm00(15:18))); log((y0+P*Y)/out00); wel11z]

% case fixentry: This is the extenive intensive margin table
rhos=0;
rhom=1;
zerorated=0;
fixentry=1;
Eqmext=eqm_solve();
Dynext=decomp(Eqmext,Eqm00);
welext=cvfunc(Eqm00(20))/out00;
fixentry=0;
fprintf('Ext/Int Table Column 1\n')
100*[-theta*log(Eqm01(4)/Eqm00(4)); log(Eqm01(7)/Eqm00(7)); ...
  log(Eqm01(6)/Eqm00(6)); Dyn01'; ...
  log(Eqm01(19)/Eqm00(19)); log(Eqm01(13)/Eqm00(13)); log(Eqm01(14)/Eqm00(14)); ...
  log(sum(Eqm01(15:18))/sum(Eqm00(15:18))); log((y0+P*Y)/out00); log(Eqm01(25)/Eqm00(25)); wel01]
fprintf('Ext/Int Table Column 2\n')
100*[-theta*log(Eqmext(4)/Eqm00(4)); log(Eqmext(7)/Eqm00(7)); ...
  log(Eqmext(6)/Eqm00(6)); Dynext'; ...
  log(Eqmext(19)/Eqm00(19)); log(Eqmext(13)/Eqm00(13)); log(Eqmext(14)/Eqm00(14)); ...
  log(sum(Eqmext(15:18))/sum(Eqm00(15:18))); log((y0+P*Y)/out00); welext]
100*[wel01 welext wel01/welext/100]


%% Figure 1: Laffer curve for all cases and Welfare on the same graph.
nfig=0;
n=100;
Taus=linspace(0,0.25,n);
% Banchmark case:
rhos=0;
rhom=0;
zerorated=0;
tr00=zeros(n,1);
util00=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr00(j)=R(19);
    util00(j)=R(20);
end

% peak point= 0.176;
% Case 1:
rhos=0;
rhom=1;
zerorated=0;
tr01=zeros(n,1);
util01=zeros(n,1);

for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr01(j)=R(19);
    util01(j)=R(20);
end


% Case 2:
rhos=1;
rhom=0;
zerorated=0;
tr10=zeros(n,1);
util10=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr10(j)=R(19);
    util10(j)=R(20);
end

% Case 3:
rhos=1;
rhom=0;
zerorated=1;
tr10z=zeros(n,1);
util10z=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr10z(j)=R(19);
    util10z(j)=R(20);
end

% Case 4:
rhos=1;
rhom=1;
zerorated=0;
tr11=zeros(n,1);
util11=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr11(j)=R(19);
    util11(j)=R(20);
end

% Case 5:
rhos=1;
rhom=1;
zerorated=1;
tr11z=zeros(n,1);
util11z=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr11z(j)=R(19);
    util11z(j)=R(20);
end

nfig=nfig+1;
figure(nfig)
subplot(1,2,1);
hold on
title('VAT Laffer Curves')
plot(Taus,tr00,'b--*','LineWidth',2,'MarkerSize',4,'Color',[0.4 0.4 0.6])
plot(Taus,tr01,'b-o','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.8])
plot(Taus,tr10,'r--','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
plot(Taus,tr10z,'k:+','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.2])
plot(Taus,tr11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0])
plot(Taus,tr11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
xlabel('VAT Rate');
ylabel('Total Tax Revenue');
legend('Benchmark','Regime 1','Regime 2','Regime 3','Regime 4','Regime 5');

subplot(1,2,2);
hold on
title('Period Utility')
plot(Taus,util00,'b--*','LineWidth',2,'MarkerSize',4,'Color',[0.4 0.4 0.6])
plot(Taus,util01,'b-o','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.8])
plot(Taus,util10,'r--','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
plot(Taus,util10z,'k:+','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.2])
plot(Taus,util11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0])
plot(Taus,util11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
xlabel('VAT Rate');
ylabel('Period Utility');
legend('Benchmark','Regime 1','Regime 2','Regime 3','Regime 4','Regime 5');



%% Figure 2: Tax revenue breakdown
n=500;
Taus=linspace(0,0.65,n);
% Banchmark case:
rhos=1;
rhom=1;
zerorated=0;
ttax00=zeros(n,1);
tvat00=zeros(n,1);
tk00=zeros(n,1);
tw00=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tvat00(j)=R(18);
    tk00(j)=R(14);
    tw00(j)=R(13);
    ttax00(j)=R(19);
end

%nfig=nfig+1;
%figure(nfig)
subplot(1,2,2); 
hold on
%title('Laffer Curves under Different VAT Regimes')
%plot(Taus,util01,'b-o','LineWidth',2,'MarkerSize',4);%,'Color',[0.2 0.2 0.8]);
%plot(Taus,util10,'r--','LineWidth',2,'MarkerSize',4);%,'Color',[0.8 0.2 0])
%plot(Taus,util10z,'k:+','LineWidth',2,'MarkerSize',4);%,'Color',[0.2 0.2 0.2]);
%plot(Taus,util11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0]);
%plot(Taus,util11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
%plot(Taus,util01p,'r-+','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
%plot(Taus,util00,'g','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0.8]);

plot(Taus,ttax00,'b-','LineWidth',1,'Color',[0.2 0.2 0.8]);
plot(Taus,tvat00,'r--','LineWidth',1,'Color',[0.8 0.2 0]);
plot(Taus,tk00,'k:','LineWidth',1,'Color',[0.2 0.2 0.2]);
plot(Taus,tw00,'g-.','LineWidth',1,'Color',[0.2 0.8 0]);

title('Components of Total Tax Revenue Benchmark Regime');

xlabel('VAT Rate');
ylabel('Tax Revenue');
legend('Total Tax','VAT','Capital Tax','Payroll Tax');

%% Table 2: Tax neutral analysis at tau=0.17
% Find eqm with rhom=rhos=0 at tau=0.17 (calibrated value). Record eqm values
tmax=0.172; % peak point of the Laffer of under benchmark
tau=0.1633;
tauold=tau;
rhos=0;
rhom=0;
zerorated=0;

Eqm00=eqm_solve();
out00=y0+P*Y;
p0=P;

% Case 1:
rhos=0;
rhom=1;
zerorated=0;
tau_pol=fzero(@(t) tfunc(t,Eqm00(19),1),[0.0,tmax],options);
tau=tau_pol;
Eqm01t=eqm_solve();
Dyn01t=decomp(Eqm01t,Eqm00);
wel01t=cvfunc(Eqm00(20))/out00;%/(y0+P*Y);
% column 1:
fprintf('Table 2 Column 1\n')
100*[tau;-theta*log(Eqm01t(4)/Eqm00(4)); log(Eqm01t(7)/Eqm00(7)); ...
  log(Eqm01t(6)/Eqm00(6)); log(Eqm01t(11)/Eqm00(11));  ...
  log((y0+P*Y)/out00); wel01t]

% Case 2:
rhos=1;
rhom=0;
zerorated=0;
tau_pol=fzero(@(t) tfunc(t,Eqm00(19),1),[0.0,tmax],options);
tau=tau_pol;
Eqm10t=eqm_solve();
wel10t=cvfunc(Eqm00(20))/out00;%/(y0+P*Y);
% column 1:
fprintf('Table 2 Column 2\n')
100*[tau;-theta*log(Eqm10t(4)/Eqm00(4)); log(Eqm10t(7)/Eqm00(7)); ...
  log(Eqm10t(6)/Eqm00(6)); log(Eqm10t(11)/Eqm00(11));  ...
  log((y0+P*Y)/out00); wel10t]

% Case 3:
rhos=1;
rhom=0;
zerorated=1;
tau_pol=fzero(@(t) tfunc(t,Eqm00(19),1),[0.0,tmax],options);
tau=tau_pol;
Eqm10zt=eqm_solve();
wel10zt=cvfunc(Eqm00(20))/out00;%/(y0+P*Y);
% column 1:
fprintf('Table 2 Column 3\n')
100*[tau;-theta*log(Eqm10zt(4)/Eqm00(4)); log(Eqm10zt(7)/Eqm00(7)); ...
  log(Eqm10zt(6)/Eqm00(6)); log(Eqm10zt(11)/Eqm00(11));  ...
  log((y0+P*Y)/out00); wel10zt]

% Case 4:
rhos=1;
rhom=1;
zerorated=0;
tau_pol=fzero(@(t) tfunc(t,Eqm00(19),1),[0.0,tmax],options);
tau=tau_pol;
Eqm11t=eqm_solve();
wel11t=cvfunc(Eqm00(20))/out00;%/(y0+P*Y);
% column 1:
fprintf('Table 2 Column 4\n')
100*[tau;-theta*log(Eqm11t(4)/Eqm00(4)); log(Eqm11t(7)/Eqm00(7)); ...
  log(Eqm11t(6)/Eqm00(6)); log(Eqm11t(11)/Eqm00(11));  ...
  log((y0+P*Y)/out00); wel11t]

% Case 5:
rhos=1;
rhom=1;
zerorated=1;
tau_pol=fzero(@(t) tfunc(t,Eqm00(19),1),[0.0,tmax],options);
tau=tau_pol;
Eqm11zt=eqm_solve();
wel11zt=cvfunc(Eqm00(20))/out00;%/(y0+P*Y);
% column 1:
fprintf('Table 2 Column 5\n')
100*[tau;-theta*log(Eqm11zt(4)/Eqm00(4)); log(Eqm11zt(7)/Eqm00(7)); ...
  log(Eqm11zt(6)/Eqm00(6)); log(Eqm11zt(11)/Eqm00(11));  ...
  log((y0+P*Y)/out00); wel11zt]

%% Figure 3a: Change the VAT rate and compute tax-neutral welfare gains under each regime. upward sloping
n=100;
tmax=0.172;
Taus=linspace(0.0,tmax,n);
% Banchmark case:
rhos=0;
rhom=0;
zerorated=0;
tr00=zeros(n,1);
u00=zeros(n,1);
out00=(y0+P*Y);
phistars=zeros(n,2);
for j=1:n
    tau=Taus(j);
    tauold=tau;
    R=eqm_solve();
    tr00(j)=R(19);
    u00(j)=R(20);
    phistars(j,1)=phistar;
end

% Case 1:
rhos=0;
rhom=1;
zerorated=0;
cv01=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
    tau=tau_pol;
    R=eqm_solve();    
    cv01(j)=100*cvfunc(u00(j))/out00;
end

% Case 2:

rhos=1;
rhom=0;
zerorated=0;
cv10=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
    tau=tau_pol;
    R=eqm_solve();
    cv10(j)=100*cvfunc(u00(j))/out00;
end

% Case 3:

rhos=1;
rhom=1;
zerorated=0;
cv11=zeros(n,1);
for j=1:n    
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
    tau=tau_pol;
    R=eqm_solve();
    cv11(j)=100*cvfunc(u00(j))/out00;
end

% Case 4:

rhos=1;
rhom=1;
zerorated=1;
cv11z=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
    tau=tau_pol;
    R=eqm_solve();
    cv11z(j)=100*cvfunc(u00(j))/out00;
end

% Case 5:

rhos=1;
rhom=0;
zerorated=1;
cv10z=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
    tau=tau_pol;
    R=eqm_solve();
    cv10z(j)=100*cvfunc(u00(j))/out00;
end

% Case 6:

% rhos=0;
% rhom=1;
% zerorated=0;
% fixentry=1;
% cv01p=zeros(n,1);
% for j=1:n
%     tauold=Taus(j);
%     tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
%     tau=tau_pol;
%     R=eqm_solve();
%     phistars(j,2)=phistar;
%     cv01p(j)=100*cvfunc(u00(j))/out00;
% end
% fixentry=0;

nfig=nfig+1;
figure(nfig)
subplot(1,2,1);
hold on
title('Tax-Neutral Welfare Gains (Low VAT rates)')
plot(Taus,cv01,'b-o','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.8])
plot(Taus,cv10,'r--','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
plot(Taus,cv10z,'k:+','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.2])
plot(Taus,cv11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0])
plot(Taus,cv11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
% plot(Taus,cv01p,'r-+','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
xlabel('VAT Rate')
ylabel('Welfare Gains (CV,%)')
%legend('Regime 4','Regime 5');
legend('Regime 1','Regime 2','Regime 3','Regime 4','Regime 5')
%legend('Regime 1','Regime 1 with profit tax')

%% Figure 3b: Change the VAT rate and compute tax-neutral welfare gains under each regime. downward sloping
n=100;
tmax=0.172;
Taus=linspace(tmax,tmax+0.1,n);
% Banchmark case:
rhos=0;
rhom=0;
zerorated=0;
tr00=zeros(n,1);
u00=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr00(j)=R(19);
    u00(j)=R(20);
end

% Case 1:

rhos=0;
rhom=1;
zerorated=0;
cv01=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[tmax,tmax+0.2],options);
    tau=tau_pol;
    R=eqm_solve();
    cv01(j)=100*cvfunc(u00(j))/(y0+P*Y);
end

% Case 2:

rhos=1;
rhom=0;
zerorated=0;
cv10=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[tmax,tmax+0.2],options);
    tau=tau_pol;
    R=eqm_solve();
    cv10(j)=100*cvfunc(u00(j))/(y0+P*Y);
end

% Case 3:

rhos=1;
rhom=1;
zerorated=0;
cv11=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[tmax,tmax+0.2],options);
    tau=tau_pol;
    R=eqm_solve();
    cv11(j)=100*cvfunc(u00(j))/(y0+P*Y);
end

% Case 4:

rhos=1;
rhom=1;
zerorated=1;
cv11z=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[tmax,tmax+0.2],options);
    tau=tau_pol;
    R=eqm_solve();
    cv11z(j)=100*cvfunc(u00(j))/(y0+P*Y);
end

% Case 5:

rhos=1;
rhom=0;
zerorated=1;
cv10z=zeros(n,1);
for j=1:n
    % tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[0.0,tmax],options);
    tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[tmax,tmax+0.2],options);
    tau=tau_pol;
    R=eqm_solve();
    cv10z(j)=100*cvfunc(u00(j))/(y0+P*Y);
end

% % Case 6:
% 
% rhos=0;
% rhom=1;
% zerorated=0;
% fixentry=1;
% cv01p=zeros(n,1);
% for j=1:n
%     tauold=Taus(j);
%     tau_pol=fzero(@(t) tfunc(t,tr00(j),1),[tmax,tmax+0.2],options);
%     tau=tau_pol;
%     R=eqm_solve();
%     phistars(j,2)=phistar;
%     cv01p(j)=100*cvfunc(u00(j))/(y0+P*Y);
% end
% fixentry=0;

subplot(1,2,2);
hold on
title('Tax-Neutral Welfare Gains (High VAT rates)')
plot(Taus,cv01,'b-o','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.8])
plot(Taus,cv10,'r--','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
plot(Taus,cv10z,'k:+','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.2])
plot(Taus,cv11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0])
plot(Taus,cv11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
% plot(Taus,cv01p,'r-+','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
xlabel('VAT Rate')
ylabel('Welfare Gains (CV,%)')
legend('Regime 1','Regime 2','Regime 3','Regime 4','Regime 5')
% legend('Regime 1','Regime 1 with profit tax')
% legend('Regime 4','Regime 5')

%% Table 3: Welfare neutral analysis at tau=0.17
% Find eqm with rhom=rhos=0 at tau=0.17 (calibrated value). Record eqm values
tmax=0.192; % peak point of the Laffer of under benchmark
tau=0.1633;
rhos=0;
rhom=0;
zerorated=0;

Eqm00=eqm_solve();
out00=y0+P*Y;
tvat0=sum(Eqm00(15:18));

% Case 1:
rhos=0;
rhom=1;
zerorated=0;
tau_pol=fzero(@(t) tfunc(t,Eqm00(20),2),[0.0,tmax],options);
tau=tau_pol;
Eqm01w=eqm_solve();
tr01w=log(Eqm01w(19)*(Eqm00(7)*Eqm00(8)+Eqm00(9)) ...
        /(Eqm01w(7)*Eqm01w(8)+Eqm01w(9))/Eqm00(19));

% column 1:
fprintf('Table 3 Column 1\n')
eqm=Eqm01w;
tvat=sum(eqm(15:18));
100*[tau;(eqm(19)-Eqm00(19))/Eqm00(19);(tvat-tvat0)/tvat0;(eqm(18)-Eqm00(18))/Eqm00(18); ...
    (eqm(15)-Eqm00(15))/Eqm00(15);(eqm(16)-Eqm00(16))/Eqm00(16); ...
    (eqm(17)-Eqm00(17))/Eqm00(17);(eqm(13)-Eqm00(13))/Eqm00(13);(eqm(14)-Eqm00(14))/Eqm00(14);tr01w]

% Case 2:
rhos=1;
rhom=0;
zerorated=0;
tau_pol=fzero(@(t) tfunc(t,Eqm00(20),2),[0.0,tmax],options);
tau=tau_pol;
Eqm10w=eqm_solve();
tr10w=log(Eqm10w(19)*(Eqm00(7)*Eqm00(8)+Eqm00(9)) ...
        /(Eqm10w(7)*Eqm10w(8)+Eqm10w(9))/Eqm00(19));

% column 2:
fprintf('Table 3 Column 2\n')
eqm=Eqm10w;
tvat=sum(eqm(15:18));
100*[tau;(eqm(19)-Eqm00(19))/Eqm00(19);(tvat-tvat0)/tvat0;(eqm(18)-Eqm00(18))/Eqm00(18); ...
    (eqm(15)-Eqm00(15))/Eqm00(15);(eqm(16)-Eqm00(16))/Eqm00(16); ...
    (eqm(17)-Eqm00(17))/Eqm00(17);(eqm(13)-Eqm00(13))/Eqm00(13);(eqm(14)-Eqm00(14))/Eqm00(14);tr10w]

% Case 3:
rhos=1;
rhom=1;
zerorated=0;
tau_pol=fzero(@(t) tfunc(t,Eqm00(20),2),[0.0,tmax],options);
tau=tau_pol;
Eqm11w=eqm_solve();
tr11w=log(Eqm11w(19)*(Eqm00(7)*Eqm00(8)+Eqm00(9)) ...
        /(Eqm11w(7)*Eqm11w(8)+Eqm11w(9))/Eqm00(19));

% column 3:
fprintf('Table 3 Column 3\n')
eqm=Eqm11w;
tvat=sum(eqm(15:18));
100*[tau;(eqm(19)-Eqm00(19))/Eqm00(19);(tvat-tvat0)/tvat0;(eqm(18)-Eqm00(18))/Eqm00(18); ...
    (eqm(15)-Eqm00(15))/Eqm00(15);(eqm(16)-Eqm00(16))/Eqm00(16); ...
    (eqm(17)-Eqm00(17))/Eqm00(17);(eqm(13)-Eqm00(13))/Eqm00(13);(eqm(14)-Eqm00(14))/Eqm00(14);tr11w]

% Case 4:
rhos=1;
rhom=1;
zerorated=1;
tau_pol=fzero(@(t) tfunc(t,Eqm00(20),2),[0.0,tmax],options);
tau=tau_pol;
Eqm11zw=eqm_solve();
tr11zw=log(Eqm11zw(19)*(Eqm00(7)*Eqm00(8)+Eqm00(9)) ...
        /(Eqm11zw(7)*Eqm11zw(8)+Eqm11zw(9))/Eqm00(19));

% column 4:
fprintf('Table 3 Column 4\n')
eqm=Eqm11zw;
tvat=sum(eqm(15:18));
100*[tau;(eqm(19)-Eqm00(19))/Eqm00(19);(tvat-tvat0)/tvat0;(eqm(18)-Eqm00(18))/Eqm00(18); ...
    (eqm(15)-Eqm00(15))/Eqm00(15);(eqm(16)-Eqm00(16))/Eqm00(16); ...
    (eqm(17)-Eqm00(17))/Eqm00(17);(eqm(13)-Eqm00(13))/Eqm00(13);(eqm(14)-Eqm00(14))/Eqm00(14);tr11zw]


% Case 5:
rhos=1;
rhom=0;
zerorated=1;
tau_pol=fzero(@(t) tfunc(t,Eqm00(20),2),[0.0,tmax],options);
tau=tau_pol;
Eqm10zw=eqm_solve();
tr10zw=log(Eqm10zw(19)*(Eqm00(7)*Eqm00(8)+Eqm00(9)) ...
        /(Eqm10zw(7)*Eqm10zw(8)+Eqm10zw(9))/Eqm00(19));

% column 5:
fprintf('Table 3 Column 5\n')
eqm=Eqm10zw;
tvat=sum(eqm(15:18));
100*[tau;(eqm(19)-Eqm00(19))/Eqm00(19);(tvat-tvat0)/tvat0;(eqm(18)-Eqm00(18))/Eqm00(18); ...
    (eqm(15)-Eqm00(15))/Eqm00(15);(eqm(16)-Eqm00(16))/Eqm00(16); ...
    (eqm(17)-Eqm00(17))/Eqm00(17);(eqm(13)-Eqm00(13))/Eqm00(13);(eqm(14)-Eqm00(14))/Eqm00(14);tr10zw]

%% Figure 4: Change the VAT rate and compute welfare-neutral tax revenue gains under each regime.
% Find eqm with rhom=rhos=0 at tau=0.17 (calibrated value). Record eqm values
tmax=0.25;
n=100;
Taus=linspace(0.0,tmax,n);
% This must start from tau>0 as for some cases benchmark gives highest
% utility
% Banchmark case:
rhos=0;
rhom=0;
zerorated=0;
tr00=zeros(n,1);
u00=zeros(n,1);
for j=1:n
    tau=Taus(j);
    R=eqm_solve();
    tr00(j)=R(19);
    u00(j)=R(20);
end



% Case 1:
rhos=0;
rhom=1;
zerorated=0;
tr01=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,u00(j),2),[0.0,tmax+0.1],options);
    tau=tau_pol;
    R=eqm_solve();
    tr01(j)=100*(R(19)-tr00(j))/tr00(j); 
end

% Case 2:
rhos=1;
rhom=0;
zerorated=0;
tr10=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,u00(j),2),[0.0,tmax+0.1],options);
    tau=tau_pol;
    R=eqm_solve();
    tr10(j)=100*(R(19)-tr00(j))/tr00(j); 
end

% Case 3:
rhos=1;
rhom=1;
zerorated=0;
tr11=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,u00(j),2),[0.0,tmax+0.1],options);
    tau=tau_pol;
    R=eqm_solve();
    tr11(j)=100*(R(19)-tr00(j))/tr00(j); 
end

% Case 4:
rhos=1;
rhom=1;
zerorated=1;
tr11z=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,u00(j),2),[0.0,tmax+0.1],options);
    tau=tau_pol;
    R=eqm_solve();
    tr11z(j)=100*(R(19)-tr00(j))/tr00(j); 
end

% Case 5:
rhos=1;
rhom=0;
zerorated=1;
tr10z=zeros(n,1);
for j=1:n
    tau_pol=fzero(@(t) tfunc(t,u00(j),2),[0.0,tmax+0.1],options);
    tau=tau_pol;
    R=eqm_solve();
    tr10z(j)=100*(R(19)-tr00(j))/tr00(j); 
end


nfig=nfig+1;
figure(nfig)
subplot(1,2,1);
hold on
title('Welfare')
plot(Taus,util01,'b-o','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.8])
plot(Taus,util10,'r--','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
plot(Taus,util10z,'k:+','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.2])
plot(Taus,util11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0])
plot(Taus,util11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
plot(Taus,util00,'m','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0.8])
xlabel('VAT Rate')
ylabel('Period Utility')
legend('Regime 1','Regime 2','Regime 3','Regime 4','Regime 5','Benchmark')

subplot(1,2,2);
hold on
title('Welfare-Neutral Tax Revenue Gains')
plot(Taus,tr01,'b-o','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.8])
plot(Taus,tr10,'r--','LineWidth',2,'MarkerSize',4,'Color',[0.8 0.2 0])
plot(Taus,tr10z,'k:+','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.2 0.2])
plot(Taus,tr11,'g-.x','LineWidth',2,'MarkerSize',4,'Color',[0.2 0.8 0])
plot(Taus,tr11z,'y--s','LineWidth',2,'MarkerSize',4,'Color',[1 0.8 0])
xlabel('VAT Rate')
ylabel('% Change in Total Revenue')
legend('Regime 1','Regime 2','Regime 3','Regime 4','Regime 5')


return

% THE END